@@ -80,7 +80,10 @@ class RecordingJobAdmin(admin.ModelAdmin):
 
     def launch_now(self, request, queryset):
         d = datetime.datetime.fromtimestamp(time.time(), pytz.UTC)
-        queryset.update(status="waiting",scheduled_start_date=d)
+        for q in queryset:
+            q.status="waiting"
+            q.scheduled_start_date=d
+            q.save()
     launch_now.short_description=_("Launch now")
 
     def wait(self, request, queryset):
